@@ -1,23 +1,17 @@
 """The configuration for the myst parser."""
+
 import dataclasses as dc
+from collections.abc import Callable, Iterable, Iterator, Sequence
 from importlib import import_module
 from typing import (
     Any,
-    Callable,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Union,
+    TypedDict,
 )
 
-from myst_parser._compat import TypedDict
 from myst_parser.warnings_ import MystWarnings
+
 from .dc_validators import (
+    any_,
     deep_iterable,
     deep_mapping,
     in_,
@@ -62,12 +56,12 @@ class UrlSchemeType(TypedDict, total=False):
 
     url: str
     title: str
-    classes: List[str]
+    classes: list[str]
 
 
 def check_url_schemes(inst: "MdParserConfig", field: dc.Field, value: Any) -> None:
     """Check that the external schemes are of the right format."""
-    if isinstance(value, (list, tuple)):
+    if isinstance(value, list | tuple):
         if not all(isinstance(v, str) for v in value):
             raise TypeError(f"'{field.name}' is not a list of strings: {value!r}")
         value = {v: None for v in value}
@@ -75,7 +69,7 @@ def check_url_schemes(inst: "MdParserConfig", field: dc.Field, value: Any) -> No
     if not isinstance(value, dict):
         raise TypeError(f"'{field.name}' is not a dictionary: {value!r}")
 
-    new_dict: Dict[str, Optional[UrlSchemeType]] = {}
+    new_dict: dict[str, UrlSchemeType | None] = {}
     for key, val in value.items():
         if not isinstance(key, str):
             raise TypeError(f"'{field.name}' key is not a string: {key!r}")
@@ -102,7 +96,7 @@ def check_url_schemes(inst: "MdParserConfig", field: dc.Field, value: Any) -> No
                 raise TypeError(
                     f"'{field.name}[{key}][classes]' is not a list of str: {val['classes']!r}"
                 )
-            new_dict[key] = val  # type: ignore
+            new_dict[key] = val  # type: ignore[assignment]
         else:
             raise TypeError(
                 f"'{field.name}[{key}]' value is not a string or dict: {val!r}"
@@ -113,7 +107,7 @@ def check_url_schemes(inst: "MdParserConfig", field: dc.Field, value: Any) -> No
 
 def check_sub_delimiters(_: "MdParserConfig", field: dc.Field, value: Any) -> None:
     """Check that the sub_delimiters are a tuple of length 2 of strings of length 1"""
-    if (not isinstance(value, (tuple, list))) or len(value) != 2:
+    if (not isinstance(value, tuple | list)) or len(value) != 2:
         raise TypeError(f"'{field.name}' is not a tuple of length 2: {value}")
     for delim in value:
         if (not isinstance(delim, str)) or len(delim) != 1:
@@ -129,7 +123,7 @@ def check_inventories(_: "MdParserConfig", field: dc.Field, value: Any) -> None:
     for key, val in value.items():
         if not isinstance(key, str):
             raise TypeError(f"'{field.name}' key is not a string: {key!r}")
-        if not isinstance(val, (tuple, list)) or len(val) != 2:
+        if not isinstance(val, tuple | list) or len(val) != 2:
             raise TypeError(
                 f"'{field.name}[{key}]' value is not a 2-item list: {val!r}"
             )
@@ -185,7 +179,7 @@ class MdParserConfig:
         """Return a string representation of the config."""
         # this replicates the auto-generated __repr__,
         # but also allows for a repr function to be defined on the field
-        attributes: List[str] = []
+        attributes: list[str] = []
         for name, val, f in self.as_triple():
             if not f.repr:
                 continue
@@ -210,7 +204,7 @@ class MdParserConfig:
         },
     )
 
-    enable_extensions: Set[str] = dc.field(
+    enable_extensions: set[str] = dc.field(
         default_factory=set,
         metadata={"validator": check_extensions, "help": "Enable syntax extensions"},
     )
@@ -231,7 +225,15 @@ class MdParserConfig:
         },
     )
 
-    url_schemes: Dict[str, Optional[UrlSchemeType]] = dc.field(
+    links_external_new_tab: bool = dc.field(
+        default=False,
+        metadata={
+            "validator": instance_of(bool),
+            "help": "Open all external links in a new tab",
+        },
+    )
+
+    url_schemes: dict[str, UrlSchemeType | None] = dc.field(
         default_factory=lambda: {
             "http": None,
             "https": None,
@@ -247,7 +249,7 @@ class MdParserConfig:
         },
     )
 
-    ref_domains: Optional[Iterable[str]] = dc.field(
+    ref_domains: Iterable[str] | None = dc.field(
         default=None,
         metadata={
             "validator": optional(
@@ -258,7 +260,7 @@ class MdParserConfig:
         },
     )
 
-    fence_as_directive: Set[str] = dc.field(
+    fence_as_directive: set[str] = dc.field(
         default_factory=set,
         metadata={
             "validator": check_fence_as_directive,
@@ -292,7 +294,7 @@ class MdParserConfig:
         },
     )
 
-    heading_slug_func: Optional[Callable[[str], str]] = dc.field(
+    heading_slug_func: Callable[[str], str] | None = dc.field(
         default=None,
         metadata={
             "validator": check_heading_slug_func,
@@ -305,7 +307,7 @@ class MdParserConfig:
         },
     )
 
-    html_meta: Dict[str, str] = dc.field(
+    html_meta: dict[str, str] = dc.field(
         default_factory=dict,
         metadata={
             "validator": deep_mapping(
@@ -317,11 +319,19 @@ class MdParserConfig:
         },
     )
 
+    footnote_sort: bool = dc.field(
+        default=True,
+        metadata={
+            "validator": instance_of(bool),
+            "help": "Move all footnotes to the end of the document, and sort by reference order",
+        },
+    )
+
     footnote_transition: bool = dc.field(
         default=True,
         metadata={
             "validator": instance_of(bool),
-            "help": "Place a transition before any footnotes",
+            "help": "Place a transition before sorted footnotes",
         },
     )
 
@@ -335,12 +345,10 @@ class MdParserConfig:
 
     # Extension specific
 
-    substitutions: Dict[str, Union[str, int, float]] = dc.field(
+    substitutions: dict[str, Any] = dc.field(
         default_factory=dict,
         metadata={
-            "validator": deep_mapping(
-                instance_of(str), instance_of((str, int, float)), instance_of(dict)
-            ),
+            "validator": deep_mapping(instance_of(str), any_, instance_of(dict)),
             "merge_topmatter": True,
             "help": "Substitutions mapping",
             "extension": "substitutions",
@@ -348,7 +356,7 @@ class MdParserConfig:
         },
     )
 
-    sub_delimiters: Tuple[str, str] = dc.field(
+    sub_delimiters: tuple[str, str] = dc.field(
         default=("{", "}"),
         repr=False,
         metadata={
@@ -453,7 +461,7 @@ class MdParserConfig:
         },
     )
 
-    inventories: Dict[str, Tuple[str, Optional[str]]] = dc.field(
+    inventories: dict[str, tuple[str, str | None]] = dc.field(
         default_factory=dict,
         repr=False,
         metadata={
@@ -475,7 +483,7 @@ class MdParserConfig:
         return dc.replace(self, **kwargs)
 
     @classmethod
-    def get_fields(cls) -> Tuple[dc.Field, ...]:
+    def get_fields(cls) -> tuple[dc.Field, ...]:
         """Return all attribute fields in this class."""
         return dc.fields(cls)
 
@@ -483,7 +491,7 @@ class MdParserConfig:
         """Return a dictionary of field name -> value."""
         return dc.asdict(self, dict_factory=dict_factory)
 
-    def as_triple(self) -> Iterable[Tuple[str, Any, dc.Field]]:
+    def as_triple(self) -> Iterable[tuple[str, Any, dc.Field]]:
         """Yield triples of (name, value, field)."""
         fields = {f.name: f for f in dc.fields(self.__class__)}
         for name, value in dc.asdict(self).items():
@@ -492,7 +500,7 @@ class MdParserConfig:
 
 def merge_file_level(
     config: MdParserConfig,
-    topmatter: Dict[str, Any],
+    topmatter: dict[str, Any],
     warning: Callable[[MystWarnings, str], None],
 ) -> MdParserConfig:
     """Merge the file-level topmatter with the global config.
@@ -503,7 +511,7 @@ def merge_file_level(
     :returns: A new config object
     """
     # get updates
-    updates: Dict[str, Any] = {}
+    updates: dict[str, Any] = {}
     myst = topmatter.get("myst", {})
     if not isinstance(myst, dict):
         warning(MystWarnings.MD_TOPMATTER, f"'myst' key not a dict: {type(myst)}")
@@ -555,7 +563,7 @@ class TopmatterReadError(Exception):
     """Topmatter parsing error."""
 
 
-def read_topmatter(text: Union[str, Iterator[str]]) -> Optional[Dict[str, Any]]:
+def read_topmatter(text: str | Iterator[str]) -> dict[str, Any] | None:
     """Read the (optional) YAML topmatter from a source string.
 
     This is identified by the first line starting with `---`,
@@ -577,7 +585,7 @@ def read_topmatter(text: Union[str, Iterator[str]]) -> Optional[Dict[str, Any]]:
         return None
     top_matter = []
     for line in text:
-        if line.startswith("---") or line.startswith("..."):
+        if line.startswith(("---", "...")):
             break
         top_matter.append(line.rstrip() + "\n")
     try:
